@@ -313,6 +313,8 @@ func newContainers(config *OperatorConfig, features map[string]bool) []corev1.Co
 	args := []string{
 		"--logtostderr=true",
 		"--v=3",
+		"--leader-elect=true",
+		"--leader-elect-lease-duration=120s",
 		fmt.Sprintf("--namespace=%s", config.TargetNamespace),
 	}
 
